CorsOptions

Enum CorsOptions 

#[non_exhaustive]
pub enum CorsOptions { Disabled, AllowOrigins(Vec<HeaderValue>), AllowAnyOrigin, }
Available on crate feature server only.
Browser origin policy for HTTP CORS and WebSocket upgrades.

This is not authentication: requests without an Origin header are accepted by the origin check. Enforce authentication in the host router.

Prefer the constructors; matches outside this crate must include a wildcard arm to accommodate future policies:

use agent_client_protocol_http::CorsOptions;

let policy = CorsOptions::disabled();
let disabled = match policy {
    CorsOptions::Disabled => true,
    _ => false,
};
assert!(disabled);
ⓘ
use agent_client_protocol_http::CorsOptions;

let policy = CorsOptions::disabled();
match policy {
    CorsOptions::Disabled => {},
    CorsOptions::AllowOrigins(_) => {},
    CorsOptions::AllowAnyOrigin => {},
}

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


Disabled

Disable cross-origin HTTP access and reject WebSocket browser origins.



AllowOrigins(Vec<HeaderValue>)

Allow only the listed browser origins.



AllowAnyOrigin

Allow all browser origins. Does not enable credentialed CORS.

Implementations

Source

impl CorsOptions

pub fn disabled() -> Self

Disable cross-origin browser access.

pub fn allow_any_origin() -> Self

Allow any browser origin, without enabling credentialed CORS.

pub fn allow_origins<I, S>(origins: I) -> Result<Self, InvalidHeaderValue>
where I: IntoIterator<Item = S>, S: AsRef<str>,

Allow the given browser origins.