pub struct HttpClient { /* private fields */ }Available on crate feature
client only.Implementations
Sourceimpl HttpClient
impl HttpClient
Sourcepub fn new(base_url: impl AsRef<str>) -> Result<Self, HttpClientError>
pub fn new(base_url: impl AsRef<str>) -> Result<Self, HttpClientError>
Create a client from a base URL and target the standard ACP endpoint.
If the URL path is empty, /acp is used. Otherwise /acp is appended
unless the path already ends with /acp.
Sourcepub fn with_endpoint(endpoint: impl AsRef<str>) -> Result<Self, HttpClientError>
pub fn with_endpoint(endpoint: impl AsRef<str>) -> Result<Self, HttpClientError>
Create a client that targets the exact endpoint URL.
Use this when connecting to a server configured with a custom
ServerOptions::path.
Sourcepub fn with_client(
base_url: impl AsRef<str>,
http: Client,
) -> Result<Self, HttpClientError>
pub fn with_client( base_url: impl AsRef<str>, http: Client, ) -> Result<Self, HttpClientError>
Create a client with a custom HTTP client and the standard ACP endpoint.
If the URL path is empty, /acp is used. Otherwise /acp is appended
unless the path already ends with /acp.
Sourcepub fn with_endpoint_and_client(
endpoint: impl AsRef<str>,
http: Client,
) -> Result<Self, HttpClientError>
pub fn with_endpoint_and_client( endpoint: impl AsRef<str>, http: Client, ) -> Result<Self, HttpClientError>
Create a client with a custom HTTP client and exact endpoint URL.
Use this when connecting to a server configured with a custom
ServerOptions::path.